==> xoonips-2.00a.tar.gz: xoonips-2.00a/xoonips/language/english/blocks.php <==
<?php
/* constant strings
 * $Revision: 1.6.4.2 $
 */

// _MB_<MODULENAME>_<STRINGNAME>

// xnp login block
define("_MB_XOONIPS_ITEM_SEARCH_LABEL","Search");
define("_MB_XOONIPS_ITEM_ALL_LABEL","ALL");
define("_MB_XOONIPS_ITEM_TITLE_AND_KEYWORD_LABEL","Title & Keyword");

// xnp login block
define("_MB_XOONIPS_ACCOUNT_RNOW","Register now!");
define("_MB_XOONIPS_ACCOUNT_LPASS","Lost Password?");
define("_MB_XOONIPS_ACCOUNT_USERNAME","User Name");
define("_MB_XOONIPS_ACCOUNT_PASSWORD","Password");
define("_MB_XOONIPS_ACCOUNT_LOGIN","Login");

// user menu block
define("_MB_XOONIPS_ACCOUNT_VIEW_ACCOUNT", "View Account" );
define("_MB_XOONIPS_ACCOUNT_EDIT_ACCOUNT", "Edit Account" );
define("_MB_XOONIPS_ACCOUNT_GROUP_LIST", "Group List" );
define("_MB_XOONIPS_ACCOUNT_LISTING_ITEM", "Listing Item" );
define("_MB_XOONIPS_ACCOUNT_EDIT_PRIVATE_INDEX", "Edit Private Tree" );
define("_MB_XOONIPS_ACCOUNT_ADVANCED_SEARCH", "Advanced Search" );
define("_MB_XOONIPS_ACCOUNT_REGISTER_ITEM", "Contribute New Item" );
define("_MB_XOONIPS_ACCOUNT_METADATA_SEARCH_LABEL", "Metadata Search" );
define("_MB_XOONIPS_ACCOUNT_IMPORT", "Import" );

// group admin menu block
define("_MB_XOONIPS_ACCOUNT_EDIT_GROUPS", "Edit Groups" );
define("_MB_XOONIPS_ACCOUNT_CERTIFY_GROUP_ITEMS", "Certify Group Items" );
define("_MB_XOONIPS_ACCOUNT_EDIT_GROUP_INDEX", "Edit Group Tree" );

// moderator menu block
define("_MB_XOONIPS_MODERATOR_EDIT_GROUPS", "Edit Groups" );
define("_MB_XOONIPS_MODERATOR_CERTIFY_USERS", "Certify Users" );
define("_MB_XOONIPS_MODERATOR_CERTIFY_PUBLIC_ITEMS", "Certify Public Items" );
define("_MB_XOONIPS_MODERATOR_EDIT_PUBLIC_INDEX", "Edit Public Tree" );
define("_MB_XOONIPS_MODERATOR_EVENT_LOG", "Event Log" );
define("_MB_XOONIPS_MODERATOR_IMPORT", "Import" );

?>

==> xoonips-3.24a.tar.gz: xoonips-3.24a/xoonips/language/english/blocks.php <==
<?php
/* constant strings
 * $Revision: 1.17 $
 */

// _MB_<MODULENAME>_<STRINGNAME>

// xnp search block
define("_MB_XOONIPS_ITEM_SEARCH_LABEL","Search");
define("_MB_XOONIPS_ITEM_ADVANCED_SEARCH_LABEL","Advanced");
define("_MB_XOONIPS_ITEM_ALL_LABEL","ALL");
define("_MB_XOONIPS_ITEM_TITLE_AND_KEYWORD_LABEL","Title & Keyword");
define("_MB_XOONIPS_ITEM_METADATA_LABEL","Metadata");

// xnp login block
define("_MB_XOONIPS_ACCOUNT_RNOW","Register now!");
define("_MB_XOONIPS_ACCOUNT_LPASS","Lost Password?");
define("_MB_XOONIPS_ACCOUNT_USERNAME","User Name");
define("_MB_XOONIPS_ACCOUNT_PASSWORD","Password");
define("_MB_XOONIPS_ACCOUNT_LOGIN","Login");

// user menu block
define("_MB_XOONIPS_ACCOUNT_VIEW_ACCOUNT", "View Account" );
define("_MB_XOONIPS_ACCOUNT_EDIT_ACCOUNT", "Edit Account" );
define("_MB_XOONIPS_ACCOUNT_SHOW_USERS", "User List" );
define("_MB_XOONIPS_ACCOUNT_GROUP_LIST", "Group List" );
define("_MB_XOONIPS_ACCOUNT_LISTING_ITEM", "Listing Item" );
define("_MB_XOONIPS_ACCOUNT_EDIT_PRIVATE_INDEX", "Edit Private Tree" );
define("_MB_XOONIPS_ACCOUNT_ADVANCED_SEARCH", "Advanced Search" );
define("_MB_XOONIPS_ACCOUNT_REGISTER_ITEM", "Add New Item" );
define("_MB_XOONIPS_ACCOUNT_METADATA_SEARCH_LABEL", "Metadata Search" );
define("_MB_XOONIPS_ACCOUNT_IMPORT", "Import" );

// group admin menu block
define("_MB_XOONIPS_ACCOUNT_EDIT_GROUPS", "Edit Groups" );
define("_MB_XOONIPS_ACCOUNT_CERTIFY_GROUP_ITEMS", "Certify Group Items" );
define("_MB_XOONIPS_ACCOUNT_EDIT_GROUP_INDEX", "Edit Group Tree" );

// moderator menu block
define("_MB_XOONIPS_MODERATOR_EDIT_GROUPS", "Edit Groups" );
define("_MB_XOONIPS_MODERATOR_CERTIFY_USERS", "Certify Users" );
define("_MB_XOONIPS_MODERATOR_CERTIFY_PUBLIC_ITEMS", "Certify Public Items" );
define("_MB_XOONIPS_MODERATOR_EDIT_PUBLIC_INDEX", "Edit Public Tree" );
define("_MB_XOONIPS_MODERATOR_EVENT_LOG", "Event Log" );
define("_MB_XOONIPS_MODERATOR_IMPORT", "Import" );

define('_MB_XOONIPS_RANKING_VIEWED_ITEM', 'most accessed items' );
define('_MB_XOONIPS_RANKING_DOWNLOADED_ITEM', 'most downloaded items' );
define('_MB_XOONIPS_RANKING_CONTRIBUTING_USER', 'most active contributors' );
define('_MB_XOONIPS_RANKING_SEARCHED_KEYWORD', 'most searched keywords' );
define('_MB_XOONIPS_RANKING_CONTRIBUTED_GROUP', 'most active groups' );

define('_MB_XOONIPS_RANKING_NEW_ITEM', 'newly arrived items' );
define('_MB_XOONIPS_RANKING_NEW_GROUP', 'newly created groups' );
define("_MB_XOONIPS_RANKING_EMPTY", "ranking is empty."); 
define("_MB_XOONIPS_RANKING_RANK_STR", "st,nd,rd,th"); // 1st, 2nd, 3rd, 4th, ...

define("_MB_XOONIPS_SU_START", "Start su"); 
define("_MB_XOONIPS_SU_END", "End su (<b>%s</b>)"); 

?>
